import 'dart:math';

import 'package:flutter/material.dart';

import '../entities/cell.dart';
import '../layout/board.dart';
import '../provider/data.dart';
import '../utils/board_utils.dart';

class Game {

  static Container buildGameWidget(Data myProvider) {
    return Container(
      child: Column(
        mainAxisAlignment: MainAxisAlignment.start,
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          Board.buildGameBoard(myProvider),
          SizedBox(height: 2),
          Game.buildSelectCellValueBar(myProvider)
        ],
      ),
    );
  }


  static Container buildSelectCellValueBar(Data myProvider) {
    List cells = myProvider.cells;

    Color borderColor = Colors.blue;

    bool isCellSelected = (myProvider.currentCellCol != null && myProvider.currentCellRow != null);
    bool isUpdatableCellSelected = isCellSelected ? !myProvider.cells[myProvider.currentCellRow][myProvider.currentCellCol].isFixed : false;
    int maxValue = myProvider.blockSizeHorizontal * myProvider.blockSizeVertical;

    return Container(
      margin: EdgeInsets.all(2),
      padding: EdgeInsets.all(2),

      child: Table(
        defaultColumnWidth: IntrinsicColumnWidth(),
        children: [
          TableRow(
            children: [
              for (var value = 0; value <= maxValue; value++)
                Column(
                  children: [
                    Cell(
                      isUpdatableCellSelected ? value : 0,
                      false
                    ).widgetUpdateValue(myProvider)
                  ]
                ),
            ]
          ),
        ]
      ),
    );
  }

}
